/*
 *	linux/drivers/video/i830/i830.h
 *	-- Intel 830 framebuffer device header file
 *
 *	Copyright (C) 2004 Frank Zirkelbach <hackbard@hackdaworld.dyndns.org>
 *	All Rights Reserved
 *
 *	This driver is subject to the terms of the GNU General Public License.
 *	See file COPYING in the main directory for more details.
 *
 */

#ifndef __I830_H__
#define __I830_H__

/* variable types
struct mode_registers {
	u32 pixclock, M, N, P;
	u8 cr00, cr01, cr02, cr03;
	u8 cr04, cr05, cr06, cr07;
	u8 cr09, cr10, cr11, cr12;
	u8 cr13, cr15, cr16, cr30;
	u8 cr31, cr32, cr33, cr35, cr39;
	u32 bpp8_100, bpp16_100, bpp24_100;
	u32 bpp8_133, bpp16_133, bpp24_133;
	u8 msr;
};
struct state_registers {
	u32 dclk_1d, dclk_2d, dclk_0ds;
	u32 pixconf, fw_blc, pgtbl_ctl;
	u32 fence0, hws_pga, dplystas;
	u16 bltcntl, hwstam, ier, iir, imr;
	u8 cr00, cr01, cr02, cr03, cr04;
	u8 cr05, cr06, cr07, cr08, cro9;
	u8 cr10, cr11, cr12, cr13, cr14;
	u8 cr15, cr16, cr17, cr80, gr10;
	u8 cr30, cr31, cr32, cr33, cr35;
	u8 cr39, cr41, cr70, sr01, msr;
};
struct gtt_data {
	struct agp_memory *i830_fb_mem;
	struct agp_memory *i830_cursor_mem;
};
struct mem_region {
	unsigned long physical;
	__u8 *virtual;
	u32 offset;
	u32 size;
};
struct i830fb_par {
	struct mode_registers	regs;
	struct state_registers	hw_state;
	struct gtt_data		i830_gtt;
	struct fb_ops		i830fb_ops;
	struct pci_dev		*dev; /* pci device */
	struct mem_region	aperture; /* aperture memory  region */
	struct mem_region	mmio; /* memory mapped region */
	struct mem_region	fb; /* framebuffer memory region */
	struct mem_region	ring; /* ringbuffer memory region */
	struct mem_region	cursor;
	struct vga_state	state;
	drm_agp_t		*drm_agp;
	atomic_t		use_count;
	u32			pseudo_palette[17];
	u32 			pci_state[16];	
	u32			pitch;
	u32			pixconf;
	u32			watermark;
	u32			mem_freq;
	u32			res_flags; /* resource flags */
#define FB_MEM_REGION_REQ		1
#define MMIO_MEM_REGION_REQ		2
#define PCI_DEVICE_ENABLED		4
	u32			dev_flags;
	u32			cur_tail;
	u32			depth;
	u32			blit_bpp;
	u32			ovract;
	u32			cur_state;
	int			mtrr_reg;
	u16			bltcntl;
	u8			interlace;
};

/* general defines */
#define MMIO_SIZE			(512 * 1024)
#define RINGBUF_SIZE			(64 * 1024)
#define CURSOR_SIZE			(4 * 1024)

/* function prototypes */
i830fb_init_pci();
i830fb_remove_pci();
i830fb_suspend();
i830fb_resume();
i830fb_open();
i830fb_release();
i830fb_check_var();
i830fb_set_par();
i830fb_setcolreg();
i830fb_blank();
i830fb_pan_display();
i830fb_fillrect();
i830fb_copyarea();
i830fb_imageblit();
i830fb_cursor();
i830fb_sync();
i830fb_ioctl();
i830fb_release_resource();



#endif /* __I830_H__ */
